==> haskell-hslua-1.0.3.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 1.0.3.2
id: hslua-1.0.3.2-GyIcQV6t6pqKm6RAGZM965
key: hslua-1.0.3.2-GyIcQV6t6pqKm6RAGZM965
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2019 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
homepage: https://hslua.github.io/
synopsis: Bindings to Lua, an embeddable scripting language
description:
    HsLua provides bindings, wrappers, types, and helper
    functions to bridge Haskell and <https://www.lua.org/ Lua>.
    .
    This package contains a full Lua interpreter version 5.3.5.
    If you want to link it with a system-wide Lua installation,
    use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: 5c49d11b47963a788ee2f3682763c7e7
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Core Foreign.Lua.Core.Constants
    Foreign.Lua.Core.Error Foreign.Lua.Core.RawBindings
    Foreign.Lua.Core.Types Foreign.Lua.FunctionCalling
    Foreign.Lua.Module Foreign.Lua.Types Foreign.Lua.Types.Peekable
    Foreign.Lua.Types.Pushable Foreign.Lua.Userdata Foreign.Lua.Util
hidden-modules: Foreign.Lua.Utf8 Foreign.Lua.Core.Auxiliary
                Foreign.Lua.Core.Functions
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-1.0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-1.0.3.2
hs-libraries: HShslua-1.0.3.2-GyIcQV6t6pqKm6RAGZM965
extra-libraries:
    lua m
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.4-H1XGt2c1wDKAUfq89wm0aB mtl-2.2.2 text-1.2.3.1
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-1.0.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 1.0.3
id: hslua-1.0.3-16GrMe3t1eKDuaRSpE3P3S
key: hslua-1.0.3-16GrMe3t1eKDuaRSpE3P3S
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2019 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
homepage: https://hslua.github.io/
synopsis: Bindings to Lua, an embeddable scripting language
description:
    HsLua provides bindings, wrappers, types, and helper
    functions to bridge Haskell and <https://www.lua.org/ Lua>.
    .
    This package contains a full Lua interpreter version 5.3.5.
    If you want to link it with a system-wide Lua installation,
    use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: f31c8028ecd9b1232ed976ddccbe583c
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Core Foreign.Lua.Core.Constants
    Foreign.Lua.Core.Error Foreign.Lua.Core.RawBindings
    Foreign.Lua.Core.Types Foreign.Lua.FunctionCalling
    Foreign.Lua.Module Foreign.Lua.Types Foreign.Lua.Types.Peekable
    Foreign.Lua.Types.Pushable Foreign.Lua.Userdata Foreign.Lua.Util
hidden-modules: Foreign.Lua.Utf8 Foreign.Lua.Core.Auxiliary
                Foreign.Lua.Core.Functions
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-1.0.3
hs-libraries: HShslua-1.0.3-16GrMe3t1eKDuaRSpE3P3S
extra-libraries:
    lua m
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA mtl-2.2.2 text-1.2.3.1
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
